import globby from 'globby';
import docgen from 'react-docgen-typescript';
const getParser = (config, options, parserOptions) => {
    if (config) {
        return docgen.withCustomConfig(config, parserOptions).parse;
    }
    else if (options) {
        return docgen.withCompilerOptions(options, parserOptions).parse;
    }
    return docgen.withDefaultConfig(parserOptions).parse;
};
export default function plugin(context, { src, global = false, route, tsConfig, compilerOptions, parserOptions }) {
    return {
        name: 'docusaurus-plugin-react-docgen-typescript',
        async loadContent() {
            return getParser(tsConfig, compilerOptions, parserOptions)(await globby(src));
        },
        async contentLoaded({ content, actions }) {
            const { createData, setGlobalData, addRoute } = actions;
            if (global) {
                console.warn('Using global data can potentially slow down your entire app. Use with care ❤️');
                setGlobalData(content);
            }
            else {
                addRoute({
                    ...route,
                    modules: {
                        docgen: await createData('docgen.json', JSON.stringify(content)),
                    },
                });
            }
        },
    };
}
